@@ -16,18 +16,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.69 2004/09/01 22:11:36 chpe Exp $
+ *  $Id: downloader-view.c,v 1.82 2004/12/20 13:06:44 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h" 
-#endif
 
 #include "downloader-view.h"
 #include "ephy-file-helpers.h"
 #include "ephy-embed-shell.h"
-#include "ephy-cell-renderer-progress.h"
 #include "ephy-stock-icons.h"
+#include "ephy-gui.h"
+#include "ephy-debug.h"
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <eggstatusicon.h>
@@ -37,10 +36,15 @@
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrendererpixbuf.h>
+#include <gtk/gtkcellrendererprogress.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeviewcolumn.h>
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtkiconfactory.h>
+#include <gtk/gtkmenuitem.h>
+#include <gtk/gtkmenushell.h>
+#include <gtk/gtkmenu.h>
+#include <gtk/gtkmain.h>
 #include <libgnomeui/gnome-icon-lookup.h>
 #include <glib/gi18n.h>
 
@@ -48,6 +52,7 @@
 
 enum
 {
+	COL_STATE,
 	COL_PERCENT,
 	COL_IMAGE,
 	COL_FILE,
@@ -57,7 +62,7 @@ enum
 
 enum
 {
-	PERCENT_COL_POS,
+	PROGRESS_COL_POS,
 	FILE_COL_POS,
 	REMAINING_COL_POS
 };
@@ -76,16 +81,8 @@ struct DownloaderViewPrivate
 	GtkWidget *abort_button;
 
 	EggStatusIcon *status_icon;
-
-	long remaining_secs;
 };
 
-typedef struct
-{
-	gboolean is_paused;
-	DownloaderViewPrivate *priv;
-} ControlsInfo;
-
 enum
 {
 	PROP_WINDOW,
@@ -128,9 +125,9 @@ static GObjectClass *parent_class = NULL;
 GType
 downloader_view_get_type (void)
 {
-       static GType downloader_view_type = 0;
+       static GType type = 0;
 
-	if (downloader_view_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -145,12 +142,12 @@ downloader_view_get_type (void)
 			(GInstanceInitFunc) downloader_view_init
 		};
 
-		downloader_view_type = g_type_register_static (EPHY_TYPE_DIALOG,
-							       "DownloaderView",
-							       &our_info, 0);
+		type = g_type_register_static (EPHY_TYPE_DIALOG,
+					       "DownloaderView",
+					       &our_info, 0);
 	}
 
-	return downloader_view_type;
+	return type;
 }
 
 static void
@@ -166,11 +163,33 @@ downloader_view_class_init (DownloaderViewClass *klass)
 }
 
 static void
-status_icon_activated (EggStatusIcon *icon, DownloaderView *dv)
+show_downloader_cb (DownloaderView *dv)
 {
 	gtk_window_present (GTK_WINDOW (dv->priv->window));
 }
 
+static gboolean
+status_icon_popup_menu_cb (EggStatusIcon *icon,
+                           DownloaderView *dv)
+{
+        GtkWidget *menu, *item;
+	guint button = 0;
+
+	menu = gtk_menu_new ();
+
+	item = gtk_menu_item_new_with_mnemonic (_("_Show Downloader..."));
+	g_signal_connect_swapped (item, "activate",
+				  G_CALLBACK (show_downloader_cb), dv);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show_all (menu);
+
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+			ephy_gui_menu_position_on_panel, icon->tray_icon,
+			button, gtk_get_current_event_time ());
+
+	return TRUE;
+}
+
 static void
 show_status_icon (DownloaderView *dv)
 {
@@ -180,8 +199,10 @@ show_status_icon (DownloaderView *dv)
 	dv->priv->status_icon = egg_status_icon_new_from_pixbuf (pixbuf);
 	g_object_unref (pixbuf);
 
-	g_signal_connect (dv->priv->status_icon, "activate",
-			  G_CALLBACK (status_icon_activated), dv);
+	g_signal_connect_swapped (dv->priv->status_icon, "activate",
+				  G_CALLBACK (show_downloader_cb), dv);
+	g_signal_connect (dv->priv->status_icon, "popup-menu",
+			  G_CALLBACK(status_icon_popup_menu_cb), dv);
 }
 
 static void
@@ -299,10 +320,10 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	GtkTreePath *path;
 	GtkTreeIter iter;
 	EphyDownloadState state;
-	long total, current, remaining_secs;
+	long total, current, remaining_secs = 0;
 	char *remaining, *file, *cur_progress, *name;
 	struct tm;
-	int percent;
+	int percent = 0;
 
 	row_ref = get_row_from_download (dv, download);
 	g_return_if_fail (row_ref != NULL);
@@ -311,21 +332,15 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	state = ephy_download_get_state (download);
 	switch (state)
 	{
-	case EPHY_DOWNLOAD_FAILED:
-		percent = -2;
-		remaining_secs = 0;	
-		break;
 	case EPHY_DOWNLOAD_COMPLETED:
 		downloader_view_remove_download (dv, download);
 		return;
+	case EPHY_DOWNLOAD_PAUSED:
 	case EPHY_DOWNLOAD_DOWNLOADING:
-	case EPHY_DOWNLOAD_PAUSED:	
 		percent = ephy_download_get_percent (download);
 		remaining_secs = ephy_download_get_remaining_time (download);
 		break;
 	default:
-		percent = 0;
-		remaining_secs = 0;
 		break;
 	}
 
@@ -341,7 +356,8 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 		char *total_progress;
 
 		total_progress = gnome_vfs_format_file_size_for_display (total);
-		file = g_strdup_printf ("%s\n%s of %s", name,
+		/* translators: first %s is filename, "%s of %s" is current/total file size */
+		file = g_strdup_printf (_("%s\n%s of %s"), name,
 					cur_progress, total_progress);
 		g_free (total_progress);
 	}
@@ -363,6 +379,7 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	gtk_tree_model_get_iter (dv->priv->model, &iter, path);
 	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
 			    &iter,
+			    COL_STATE, state,
 			    COL_PERCENT, percent,
 			    COL_FILE, file,
 			    COL_REMAINING, remaining,
@@ -377,44 +394,11 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	update_buttons (dv);
 }
 
-static void
-seconds_remaining_total (EphyDownload *download, gpointer data, DownloaderView *dv)
-{
-	long secs;
-
-	secs = ephy_download_get_remaining_time (download);
-	if (secs > 0)
-	{
-		dv->priv->remaining_secs += secs;
-	}
-}
-
 static void
 update_status_icon (DownloaderView *dv)
 {
-	char *tooltip, *downloadstring, *remainingstring;
-	int downloads, remaining;
-
-	dv->priv->remaining_secs = 0;
-	g_hash_table_foreach (dv->priv->downloads_hash,
-			      (GHFunc) seconds_remaining_total, dv);
-	
-	remaining = (dv->priv->remaining_secs);
-
-	if (remaining < 60)
-	{
-		remainingstring = g_strdup_printf (ngettext ("About %d second left",
-					"About %d seconds left", remaining),
-					remaining);
-	}
-	else
-	{
-		remaining /= 60;
-		
-		remainingstring = g_strdup_printf (ngettext ("About %d minute left",
-					"About %d minutes left", remaining),
-					remaining);
-	}
+	char *downloadstring;
+	int downloads;
 
 	downloads = g_hash_table_size (dv->priv->downloads_hash);
 
@@ -422,15 +406,10 @@ update_status_icon (DownloaderView *dv)
 					"%d downloads", downloads), 
 					downloads);
 
-	tooltip = g_strdup_printf ("%s\n%s",
-					downloadstring, remainingstring);
-
 	egg_status_icon_set_tooltip (dv->priv->status_icon,
-				     tooltip, NULL);
+				     downloadstring, NULL);
 
-	g_free (tooltip);
 	g_free (downloadstring);
-	g_free (remainingstring);
 }
 
 static void
@@ -490,22 +469,21 @@ downloader_view_add_download (DownloaderView *dv,
 				       mime, GNOME_ICON_LOOKUP_FLAGS_NONE, NULL);
 	g_free (mime);
 	
-	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height);
+	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (GTK_WIDGET (dv->priv->window)),
+					   GTK_ICON_SIZE_MENU, &width, &height);
 	width *= 2;
-	height *= 2;
 
-	icon_info = gtk_icon_theme_lookup_icon (theme, icon_name, width, height);
+	icon_info = gtk_icon_theme_lookup_icon (theme, icon_name, width, 0);
 	g_free (icon_name);
 	if (icon_info == NULL) return;
 
-	icon_name = g_strdup (gtk_icon_info_get_filename (icon_info));
+	pixbuf = gdk_pixbuf_new_from_file_at_size
+		(gtk_icon_info_get_filename (icon_info), width, width, NULL);
 	gtk_icon_info_free (icon_info);
-	
-	pixbuf = gdk_pixbuf_new_from_file_at_size (icon_name, width, height, NULL);
-	g_free (icon_name);
+
 	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
 			    &iter, COL_IMAGE, pixbuf, -1);
-	if (pixbuf)
+	if (pixbuf != NULL)
 	{
 		g_object_unref (pixbuf);
 	}
@@ -518,6 +496,45 @@ selection_changed (GtkTreeSelection *selection, DownloaderView *dv)
 	update_buttons (dv);
 }
 
+static void
+progress_cell_data_func (GtkTreeViewColumn *col,
+			 GtkCellRenderer   *renderer,
+			 GtkTreeModel      *model,
+			 GtkTreeIter       *iter,
+			 gpointer           user_data)
+{
+	EphyDownloadState state;
+	const char *text = NULL;
+	int percent;
+
+	gtk_tree_model_get (model, iter,
+			    COL_STATE, &state,
+			    COL_PERCENT, &percent,
+			    -1);
+
+	switch (state)
+	{
+		case EPHY_DOWNLOAD_INITIALISING:
+			text = Q_("download status|Unknown");
+			break;
+		case EPHY_DOWNLOAD_FAILED:
+			text = Q_("download status|Failed");
+			break;
+		case EPHY_DOWNLOAD_DOWNLOADING:
+		case EPHY_DOWNLOAD_PAUSED:
+			if (percent == -1)
+			{
+				text = Q_("download status|Unknown");
+				percent = 0;
+			}
+			break;
+		default:
+			g_return_if_reached ();
+	}
+
+	g_object_set (renderer, "text", text, "value", percent, NULL);
+}
+
 static void
 downloader_view_build_ui (DownloaderView *dv)
 {
@@ -525,7 +542,6 @@ downloader_view_build_ui (DownloaderView *dv)
 	GtkListStore *liststore;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
-	GdkPixbuf *icon;
 	EphyDialog *d = EPHY_DIALOG (dv);
 	GtkTreeSelection *selection;
 
@@ -536,15 +552,19 @@ downloader_view_build_ui (DownloaderView *dv)
 			       NULL);
 
 	/* lookup needed widgets */
-	priv->window = ephy_dialog_get_control(d, properties[PROP_WINDOW].id);
-	priv->treeview = ephy_dialog_get_control (d, properties[PROP_TREEVIEW].id);
-	priv->pause_button = ephy_dialog_get_control (d, properties[PROP_PAUSE_BUTTON].id);
-	priv->abort_button = ephy_dialog_get_control (d, properties[PROP_ABORT_BUTTON].id);
+	ephy_dialog_get_controls
+		(d,
+		 properties[PROP_WINDOW].id, &priv->window,
+		 properties[PROP_TREEVIEW].id, &priv->treeview,
+		 properties[PROP_PAUSE_BUTTON].id, &priv->pause_button,
+		 properties[PROP_ABORT_BUTTON].id, &priv->abort_button,
+		 NULL);
 
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview)),
 				     GTK_SELECTION_BROWSE);
 
-	liststore = gtk_list_store_new (5,
+	liststore = gtk_list_store_new (6,
+					G_TYPE_INT,
 					G_TYPE_INT,
 					GDK_TYPE_PIXBUF,
 					G_TYPE_STRING,
@@ -576,15 +596,15 @@ downloader_view_build_ui (DownloaderView *dv)
 	gtk_tree_view_column_set_sort_column_id (column, COL_FILE);
 	gtk_tree_view_column_set_spacing (column, 3);
 
-	/* Percent column */
-	renderer = ephy_cell_renderer_progress_new ();
+	/* Progress column */
+	renderer = gtk_cell_renderer_progress_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(priv->treeview),
-						     PERCENT_COL_POS, _("%"),
+						     PROGRESS_COL_POS, _("%"),
 						     renderer,
-						     "value", COL_PERCENT,
 						     NULL);
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview), PERCENT_COL_POS);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview), PROGRESS_COL_POS);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, progress_cell_data_func, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, COL_PERCENT);
 
 	/* Remainng time column */
@@ -600,13 +620,11 @@ downloader_view_build_ui (DownloaderView *dv)
 					   REMAINING_COL_POS);
 	gtk_tree_view_column_set_sort_column_id (column, COL_REMAINING);
 
+	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (priv->treeview), FALSE);
+
 	priv->model = GTK_TREE_MODEL (liststore);
 
-	icon = gtk_widget_render_icon (GTK_WIDGET (priv->window),
-				       EPHY_STOCK_DOWNLOAD,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW(priv->window), icon);
+	gtk_window_set_icon_name (GTK_WINDOW (priv->window), EPHY_STOCK_DOWNLOAD);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
 	g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), dv);
