@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.23 2004/06/26 18:28:44 chpe Exp $
+ *  $Id: ephy-embed-single.c,v 1.28 2004/11/02 20:56:55 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-embed-single.h"
 #include "ephy-marshal.h"
@@ -32,7 +30,7 @@ ephy_embed_single_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -164,21 +162,6 @@ ephy_embed_single_get_offline_mode (EphyEmbedSingle *single)
 	return iface->get_offline_mode (single);
 }
 
-/**
- * ephy_embed_single_load_proxy_autoconf:
- * @single: the #EphyEmbedSingle
- * @url: a URL to a PAC file
- * 
- * Sets the address of the PAC file, and loads the proxy configuration from it.
- **/
-void
-ephy_embed_single_load_proxy_autoconf (EphyEmbedSingle *single,
-				       const char* url)
-{
-	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
-	iface->load_proxy_autoconf (single, url);
-}
-
 /**
  * ephy_embed_single_get_font_list:
  * @single: the #EphyEmbedSingle
@@ -205,21 +188,33 @@ ephy_embed_single_get_font_list (EphyEmbedSingle *single,
  * @single: the #EphyEmbedSingle
  * @parent: the requested window's parent #EphyEmbed
  * @address: the URL to load
+ * @name: a name for the window
  * @features: a Javascript features string
  *
  * Opens a new window, as if it were opened in @parent using the Javascript
  * method and arguments: <code>window.open(&quot;@address&quot;,
  * &quot;_blank&quot;, &quot;@features&quot;);</code>.
  * 
- * Use ephy_shell_new_tab() unless this handling of the @features string is
+ * Returns: the new embed. This is either a #EphyEmbed, or, when @features specified
+ * "chrome", a #GtkMozEmbed.
+ *
+ * NOTE: Use ephy_shell_new_tab() unless this handling of the @features string is
  * required.
  */
-void
+GtkWidget *
 ephy_embed_single_open_window (EphyEmbedSingle *single,
 			       EphyEmbed *parent,
 			       const char *address,
+			       const char *name,
 			       const char *features)
 {
 	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
-	return iface->open_window (single, parent, address, features);
+	return iface->open_window (single, parent, address, name, features);
+}
+
+GList *
+ephy_embed_single_get_printer_list (EphyEmbedSingle *single)
+{
+	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
+	return iface->get_printer_list (single);
 }
