@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.h,v 1.9 2003/11/19 19:19:55 chpe Exp $
+ *  $Id: ephy-history.h,v 1.11 2004/12/02 15:16:41 chpe Exp $
  */
 
 #ifndef EPHY_HISTORY_H
@@ -63,7 +63,14 @@ struct EphyHistoryClass
 {
         GObjectClass parent_class;
 
-	void (* visited) (const char *url);
+	/* Signals */
+	void	(* visited)	(EphyHistory *history,
+				 const char *url);
+	void	(* cleared)	(EphyHistory *history);
+
+	void	(* redirect)	(EphyHistory *history,
+				 const char *from_uri,
+				 const char *to_uri);
 };
 
 GType		ephy_history_get_type		(void);
@@ -103,6 +110,8 @@ const char     *ephy_history_get_icon		(EphyHistory *gh,
 
 void            ephy_history_clear              (EphyHistory *gh);
 
+gboolean	ephy_history_is_enabled		(EphyHistory *history);
+
 G_END_DECLS
 
 #endif
