@@ -36,14 +36,12 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyAboutRedirector.cpp,v 1.10.4.2 2004/11/17 19:41:24 chpe Exp $
+ * $Id: EphyAboutRedirector.cpp,v 1.13 2004/11/17 19:41:57 chpe Exp $
  */
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "EphyAboutRedirector.h"
 
