@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.46 2004/11/13 19:53:38 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.49 2004/12/19 13:43:21 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -42,7 +42,6 @@
 #include <nsIDOMWindowInternal.h>
 #endif
 
-#include "ephy-string.h"
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
@@ -118,6 +117,12 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 					 CONF_STATE_UPLOAD_DIR,
 					 EPHY_FILE_FILTER_NONE);
 
+	if (parent)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (gtkparent)),
+					     GTK_WINDOW (mDialog));
+	}
+
 	if (mode == nsIFilePicker::modeOpenMultiple)
 	{
 		gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (mDialog), TRUE);
