@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.cpp,v 1.31 2004/11/13 19:53:38 chpe Exp $
+ *  $Id: GlobalHistory.cpp,v 1.32 2004/12/02 15:16:41 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -37,6 +37,9 @@ NS_IMPL_ISUPPORTS2(MozGlobalHistory, nsIGlobalHistory2, nsIBrowserHistory)
 MozGlobalHistory::MozGlobalHistory ()
 {
 	mGlobalHistory = EPHY_HISTORY (ephy_embed_shell_get_global_history (embed_shell));
+
+	mHistoryListener = new EphyHistoryListener ();
+	mHistoryListener->Init (mGlobalHistory);
 }
 
 MozGlobalHistory::~MozGlobalHistory ()
