@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.h,v 1.8.4.1 2005/01/01 20:55:00 chpe Exp $
+ *  $Id: GlobalHistory.h,v 1.9 2004/12/02 15:16:41 chpe Exp $
  */
 
 #ifndef EPHY_GLOBAL_HISTORY_H
@@ -24,8 +24,14 @@
 
 #include "ephy-history.h"
 
+#include <nsIBrowserHistory.h>
 #include <nsIGlobalHistory2.h>
 
+#include <nsCOMPtr.h>
+#include <nsAutoPtr.h>
+
+#include "EphyHistoryListener.h"
+
 #define EPHY_GLOBALHISTORY_CLASSNAME	"Epiphany Global History Implementation"
 
 #define EPHY_GLOBALHISTORY_CID					\
@@ -35,7 +41,7 @@
 	{ 0xb7, 0x9e, 0xf7, 0xaa, 0x49, 0xeb, 0x6a, 0x15}	\
 }
 
-class MozGlobalHistory: public nsIGlobalHistory2
+class MozGlobalHistory: public nsIBrowserHistory
 {
 	public:
 		MozGlobalHistory ();
@@ -43,9 +49,11 @@ class MozGlobalHistory: public nsIGlobalHistory2
 
 		NS_DECL_ISUPPORTS
 		NS_DECL_NSIGLOBALHISTORY2
+		NS_DECL_NSIBROWSERHISTORY
 
 	private:
 		EphyHistory *mGlobalHistory;
+		nsRefPtr<EphyHistoryListener> mHistoryListener;
 };
 
 #endif /* EPHY_GLOBAL_HISTORY_H */
