@@ -16,14 +16,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.28.4.2 2005/02/07 23:04:45 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.32 2004/12/19 14:40:21 chpe Exp $
  */
 
 #include "mozilla-config.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ContentHandler.h"
 #include "GlobalHistory.h"
@@ -79,23 +77,22 @@ RegisterContentPolicy(nsIComponentManager *aCompMgr, nsIFile *aPath,
 		do_GetService(NS_CATEGORYMANAGER_CONTRACTID);
 	NS_ENSURE_TRUE (cm, NS_ERROR_FAILURE);
 
-	char *oldval;
-	return cm->AddCategoryEntry("content-policy",
-				    EPHY_CONTENT_POLICY_CONTRACTID,
-				    EPHY_CONTENT_POLICY_CONTRACTID,
-				    PR_TRUE, PR_TRUE, &oldval);
-	nsMemory::Free (oldval);
+	nsresult rv;
+	char *oldval = nsnull;
+	rv = cm->AddCategoryEntry ("content-policy",
+				   EPHY_CONTENT_POLICY_CONTRACTID,
+				   EPHY_CONTENT_POLICY_CONTRACTID,
+				   PR_TRUE, PR_TRUE, &oldval);
+	if (oldval)
+		nsMemory::Free (oldval);
+	return rv;
 }
 
 static const nsModuleComponentInfo sAppComps[] = {
 	{
 		MOZ_DOWNLOAD_CLASSNAME,
 		MOZ_DOWNLOAD_CID,
-#ifdef NS_TRANSFER_CONTRACTID
-		NS_TRANSFER_CONTRACTID,
-#else
 		NS_DOWNLOAD_CONTRACTID,
-#endif
 		MozDownloadConstructor
 	},
 #ifdef ENABLE_FILEPICKER
