@@ -51,7 +51,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* INT:STRING (./ephy-marshal.list:1) */
+/* INT:STRING (../../lib/ephy-marshal.list:1) */
 extern void ephy_marshal_INT__STRING (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -96,7 +96,7 @@ ephy_marshal_INT__STRING (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (./ephy-marshal.list:2) */
+/* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:2) */
 extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -141,7 +141,7 @@ ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING (./ephy-marshal.list:3) */
+/* BOOLEAN:STRING,STRING (../../lib/ephy-marshal.list:3) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -188,7 +188,7 @@ ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (./ephy-marshal.list:4) */
+/* BOOLEAN:VOID (../../lib/ephy-marshal.list:4) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -231,7 +231,10 @@ ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:ENUM,INT,BOOLEAN (./ephy-marshal.list:5) */
+/* VOID:ENUM (../../lib/ephy-marshal.list:5) */
+#define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
+
+/* VOID:ENUM,INT,BOOLEAN (../../lib/ephy-marshal.list:6) */
 extern void ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -276,7 +279,7 @@ ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT (./ephy-marshal.list:6) */
+/* VOID:INT,INT (../../lib/ephy-marshal.list:7) */
 extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -319,7 +322,7 @@ ephy_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT (./ephy-marshal.list:7) */
+/* VOID:POINTER,INT (../../lib/ephy-marshal.list:8) */
 extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -362,7 +365,7 @@ ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:8) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -405,7 +408,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./ephy-marshal.list:9) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -448,7 +451,7 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (./ephy-marshal.list:10) */
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:11) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -491,7 +494,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT,INT (./ephy-marshal.list:11) */
+/* VOID:STRING,INT,INT (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -536,7 +539,7 @@ ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (./ephy-marshal.list:12) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -579,7 +582,7 @@ ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,BOOLEAN (./ephy-marshal.list:13) */
+/* VOID:STRING,BOOLEAN (../../lib/ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
