@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.c,v 1.16 2004/04/04 18:30:33 adamh Exp $
+ *  $Id: ephy-node-db.c,v 1.19 2004/11/02 20:57:20 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-node-db.h"
 #include "ephy-file-helpers.h"
@@ -67,10 +65,12 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_node_db_get_type (void)
 {
-	static GType ephy_node_db_type = 0;
+	static GType type = 0;
 
-	if (ephy_node_db_type == 0) {
-		static const GTypeInfo our_info = {
+	if (G_UNLIKELY (type == 0))
+	{
+		static const GTypeInfo our_info =
+		{
 			sizeof (EphyNodeDbClass),
 			NULL,
 			NULL,
@@ -82,12 +82,12 @@ ephy_node_db_get_type (void)
 			(GInstanceInitFunc) ephy_node_db_init
 		};
 
-		ephy_node_db_type = g_type_register_static (G_TYPE_OBJECT,
-						       "EphyNodeDb",
-						       &our_info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyNodeDb",
+					       &our_info, 0);
 	}
 
-	return ephy_node_db_type;
+	return type;
 }
 
 static void
@@ -180,8 +180,6 @@ ephy_node_db_init (EphyNodeDb *db)
 {
 	db->priv = EPHY_NODE_DB_GET_PRIVATE (db);
 
-	db->priv->name = NULL;
-
 	/* id to node */
 	db->priv->id_to_node = g_ptr_array_new ();
 
