@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.154 2004/11/10 23:06:46 xan Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.157 2004/12/18 21:51:48 chpe Exp $
  */
 
 #include "config.h"
@@ -47,6 +47,7 @@
 
 #include "ephy-bookmarks-editor.h"
 #include "ephy-bookmarks-import.h"
+#include "ephy-bookmarks-export.h"
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-window.h"
@@ -113,6 +114,8 @@ static void cmd_bookmark_properties	  (GtkAction *action,
 					   EphyBookmarksEditor *editor);
 static void cmd_bookmarks_import	  (GtkAction *action,
 					   EphyBookmarksEditor *editor);
+static void cmd_bookmarks_export	  (GtkAction *action,
+					   EphyBookmarksEditor *editor);
 static void cmd_add_topic		  (GtkAction *action,
 					   EphyBookmarksEditor *editor);
 static void cmd_rename			  (GtkAction *action,
@@ -175,7 +178,7 @@ static GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "OpenInWindow", GTK_STOCK_OPEN, N_("_Open in New Window"), "<control>O",
 	  N_("Open the selected bookmark in a new window"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
-	{ "OpenInTab", NULL, N_("Open in New _Tab"), "<shift><control>O",
+	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected bookmark in a new tab"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
 	{ "Rename", NULL, N_("_Rename..."), "F2",
@@ -189,6 +192,9 @@ static GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "Import", NULL, N_("_Import Bookmarks..."), NULL,
 	  N_("Import bookmarks from another browser or a bookmarks file"), 
 	  G_CALLBACK (cmd_bookmarks_import) },
+	{ "Export", NULL, N_("_Export Bookmarks..."), NULL,
+	  N_("Export bookmarks to a file"), 
+	  G_CALLBACK (cmd_bookmarks_export) },	  
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
 	  N_("Close the bookmarks window"), 
 	  G_CALLBACK (cmd_close) },
@@ -448,10 +454,10 @@ cmd_open_bookmarks_in_browser (GtkAction *action,
 }
 
 static GtkWidget*
-delete_topic_dialog_construct (GtkWindow *parent, const char *topic)
+delete_topic_dialog_construct (GtkWindow *parent,
+			       const char *topic)
 {
 	GtkWidget *dialog;
-	GtkWindowGroup *group;
 	char *str;
 
 	str = g_strdup_printf (_("Delete topic %s?"), topic);
@@ -472,16 +478,7 @@ delete_topic_dialog_construct (GtkWindow *parent, const char *topic)
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Delete Topic"), GTK_RESPONSE_ACCEPT);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
-	group = GTK_WINDOW (parent)->group;
-
-	if (group == NULL)
-	{
-		group = gtk_window_group_new ();
-		gtk_window_group_add_window (group, GTK_WINDOW (parent));
-		g_object_unref (group);
-	}
-
-	gtk_window_group_add_window (group, GTK_WINDOW (dialog));
+	gtk_window_group_add_window (GTK_WINDOW (parent)->group, GTK_WINDOW (dialog));
 
         return dialog;
 }
@@ -660,6 +657,88 @@ import_dialog_response_cb (GtkDialog *dialog, gint response,
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
+static void
+cmd_bookmarks_export (GtkAction *action,
+		      EphyBookmarksEditor *editor)
+{
+	GtkWidget *dialog, *hbox, *label, *combo;
+	char *filename = NULL;
+	int response, format;
+
+	dialog = GTK_WIDGET (ephy_file_chooser_new (_("Export Bookmarks"),
+		GTK_WIDGET (editor),
+		GTK_FILE_CHOOSER_ACTION_SAVE,
+		NULL,
+		EPHY_FILE_FILTER_NONE));
+
+	gtk_file_chooser_set_current_folder
+		(GTK_FILE_CHOOSER (dialog), g_get_home_dir ());
+
+	gtk_file_chooser_set_current_name
+		(GTK_FILE_CHOOSER (dialog), _("Bookmarks"));
+
+	/* Make a format selection combo & label */
+	label = gtk_label_new (_("File format:"));
+
+	combo = gtk_combo_box_new_text ();
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Epiphany (RDF)"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Mozilla (HTML)"));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
+	
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_end (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show_all (hbox);
+	
+	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog), hbox);
+
+	gtk_window_group_add_window (GTK_WINDOW (editor)->group, GTK_WINDOW (dialog));
+
+	do
+	{
+		char *basename, *strtmp;
+
+		g_free (filename);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		format = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		basename = g_path_get_basename (filename);
+		if (basename != NULL && strchr (basename, '.') == NULL)
+		{
+			strtmp = filename;
+			if (format == 0)
+			{
+				filename = g_strconcat (filename, ".rdf", NULL);
+			}
+			else if (format == 1)
+			{
+				filename = g_strconcat (filename, ".html", NULL);
+			}
+			g_free (strtmp);
+		}
+		g_free (basename);
+	}
+	while (response == GTK_RESPONSE_ACCEPT
+	       && !ephy_gui_confirm_overwrite_file (GTK_WIDGET (dialog), filename));
+
+	gtk_widget_destroy (dialog);
+
+	/* 0 for ephy RDF format, 1 for mozilla HTML format */
+
+	if (format == 0)
+	{
+		ephy_bookmarks_export_rdf (editor->priv->bookmarks, filename);
+	}
+	else if (format == 1)
+	{
+		ephy_bookmarks_export_mozilla (editor->priv->bookmarks, filename);
+	}
+
+	g_free (filename);
+}
+
 static void
 cmd_bookmarks_import (GtkAction *action,
 		      EphyBookmarksEditor *editor)
@@ -1456,6 +1535,8 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	GtkActionGroup *action_group;
 	int col_id, details_value;
 
+	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
+
 	gtk_window_set_title (GTK_WINDOW (editor), _("Bookmarks"));
 	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_BOOKMARKS);
 
