@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.82 2004/11/11 14:17:24 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.84 2004/12/16 20:09:33 chpe Exp $
  */
 
 #include "config.h"
@@ -172,7 +172,7 @@ static GtkActionEntry ephy_history_ui_entries [] = {
 	{ "OpenInWindow", GTK_STOCK_OPEN, N_("_Open in New Window"), "<control>O",
 	  N_("Open the selected history link in a new window"),
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
-	{ "OpenInTab", NULL, N_("Open in New _Tab"), "<shift><control>O",
+	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected history link in a new tab"),
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
 	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
@@ -248,7 +248,7 @@ confirmation_dialog_response_cb (GtkWidget *dialog,
 static GtkWidget *
 confirmation_dialog_construct (EphyHistoryWindow *editor)
 {
-	GtkWidget *dialog;
+	GtkWidget *dialog, *button, *image;
 
 	dialog = gtk_message_dialog_new
 		(GTK_WINDOW (editor),
@@ -262,8 +262,13 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 		 _("Clearing the browsing history will cause all"
 		   " history links to be permanently deleted."));
 	
-	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("C_lear"), GTK_RESPONSE_ACCEPT);
+	button = gtk_button_new_with_label (_("C_lear"));
+	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (button), image);
+	gtk_widget_show (image);
+	gtk_widget_show (button);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_ACCEPT);
+	
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Clear History"));
