@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.46.4.9 2005/02/20 14:59:37 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.60 2004/12/13 18:58:58 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-notebook.h"
 #include "ephy-stock-icons.h"
@@ -36,10 +34,7 @@
 #include "ephy-shell.h"
 #include "ephy-debug.h"
 #include "ephy-favicon-cache.h"
-#include "ephy-label.h"
 #include "ephy-spinner.h"
-#include "ephy-string.h"
-#include "ephy-stock-icons.h"
 
 #include <glib-object.h>
 #include <gtk/gtkeventbox.h>
@@ -79,7 +74,6 @@ static void ephy_notebook_class_init     (EphyNotebookClass *klass);
 static void ephy_notebook_finalize       (GObject *object);
 static void move_tab_to_another_notebook (EphyNotebook *src,
 			                  EphyNotebook *dest,
-					  GdkEventMotion *event,
 					  int dest_position);
 
 /* Local variables */
@@ -109,9 +103,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_notebook_get_type (void)
 {
-        static GType ephy_notebook_type = 0;
+        static GType type = 0;
 
-        if (ephy_notebook_type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
 			{
@@ -126,12 +120,12 @@ ephy_notebook_get_type (void)
 				(GInstanceInitFunc) ephy_notebook_init
 			};
 
-                ephy_notebook_type = g_type_register_static (GTK_TYPE_NOTEBOOK,
-							     "EphyNotebook",
-							     &our_info, 0);
+                type = g_type_register_static (GTK_TYPE_NOTEBOOK,
+					       "EphyNotebook",
+					       &our_info, 0);
         }
 
-        return ephy_notebook_type;
+        return type;
 }
 
 static void
@@ -196,27 +190,6 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 	g_type_class_add_private (object_class, sizeof(EphyNotebookPrivate));
 }
 
-static gboolean
-is_in_notebook_window (EphyNotebook *notebook,
-		       gint abs_x, gint abs_y)
-{
-	gint x, y;
-	gint rel_x, rel_y;
-	gint width, height;
-	GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET(notebook));
-	GdkWindow *window = GTK_WIDGET(toplevel)->window;
-
-	gdk_window_get_origin (window, &x, &y);
-	rel_x = abs_x - x;
-	rel_y = abs_y - y;
-
-	x = GTK_WIDGET(notebook)->allocation.x;
-	y = GTK_WIDGET(notebook)->allocation.y;
-	height = GTK_WIDGET(notebook)->allocation.height;
-	width  = GTK_WIDGET(notebook)->allocation.width;
-	return ((rel_x>=x) && (rel_y>=y) && (rel_x<=x+width) && (rel_y<=y+height));
-}
-
 static EphyNotebook *
 find_notebook_at_pointer (gint abs_x, gint abs_y)
 {
@@ -224,6 +197,7 @@ find_notebook_at_pointer (gint abs_x, gint abs_y)
 	gpointer toplevel = NULL;
 	gint x, y;
 
+	/* FIXME multi-head */
 	win_at_pointer = gdk_window_at_pointer (&x, &y);
 	if (win_at_pointer == NULL)
 	{
@@ -239,20 +213,24 @@ find_notebook_at_pointer (gint abs_x, gint abs_y)
 	/* toplevel should be an EphyWindow */
 	if (toplevel != NULL && EPHY_IS_WINDOW (toplevel))
 	{
-		EphyNotebook *notebook;
-
-		notebook = EPHY_NOTEBOOK (ephy_window_get_notebook
-					    (EPHY_WINDOW (toplevel)));
-
-		if (is_in_notebook_window (notebook, abs_x, abs_y))
-		{
-			return notebook;
-		}
+		return EPHY_NOTEBOOK (ephy_window_get_notebook
+					(EPHY_WINDOW (toplevel)));
 	}
 
 	return NULL;
 }
 
+static gboolean
+is_in_notebook_window (EphyNotebook *notebook,
+		       gint abs_x, gint abs_y)
+{
+	EphyNotebook *nb_at_pointer;
+
+	nb_at_pointer = find_notebook_at_pointer (abs_x, abs_y);
+
+	return nb_at_pointer == notebook;
+}
+
 static gint
 find_tab_num_at_pos (EphyNotebook *notebook, gint abs_x, gint abs_y)
 {
@@ -362,24 +340,20 @@ ephy_notebook_move_tab (EphyNotebook *src,
 }
 
 static void
-drag_start (EphyNotebook *notebook,
-	    guint32 time)
+drag_start (EphyNotebook *notebook)
 {
 	notebook->priv->drag_in_progress = TRUE;
 
 	/* get a new cursor, if necessary */
-	/* FIXME multi-head */
 	if (!cursor) cursor = gdk_cursor_new (GDK_FLEUR);
 
 	/* grab the pointer */
 	gtk_grab_add (GTK_WIDGET (notebook));
-	/* FIXME multi-head */
-	if (!gdk_pointer_is_grabbed ())
-	{
-		gdk_pointer_grab (GTK_WIDGET (notebook)->window,
+	if (!gdk_pointer_is_grabbed ()) {
+		gdk_pointer_grab (GDK_WINDOW(GTK_WIDGET (notebook)->window),
 				  FALSE,
 				  GDK_BUTTON1_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
-				  NULL, cursor, time);
+				  NULL, cursor, GDK_CURRENT_TIME);
 	}
 }
 
@@ -439,11 +413,12 @@ motion_notify_cb (EphyNotebook *notebook,
 					      notebook->priv->y_start,
 					      event->x_root, event->y_root))
 		{
-			drag_start (notebook, event->time);
-			return TRUE;
+			drag_start (notebook);
+		}
+		else
+		{
+			return FALSE;
 		}
-
-		return FALSE;
 	}
 
 	result = find_notebook_and_tab_at_pos ((gint)event->x_root,
@@ -455,7 +430,7 @@ motion_notify_cb (EphyNotebook *notebook,
 		if (dest != notebook)
 		{
 			move_tab_to_another_notebook (notebook, dest,
-						      event, page_num);
+						      page_num);
 		}
 		else
 		{
@@ -470,15 +445,11 @@ motion_notify_cb (EphyNotebook *notebook,
 static void
 move_tab_to_another_notebook (EphyNotebook *src,
 			      EphyNotebook *dest,
-			      GdkEventMotion *event,
 			      int dest_position)
 {
 	EphyTab *tab;
 	int cur_page;
 
-	LOG ("moving tab from notebook %p to notebook %p at %d",
-	     src, dest, dest_position)
-
 	/* This is getting tricky, the tab was dragged in a notebook
 	 * in another window of the same app, we move the tab
 	 * to that new notebook, and let this notebook handle the
@@ -491,25 +462,19 @@ move_tab_to_another_notebook (EphyNotebook *src,
 	tab = EPHY_TAB (gtk_notebook_get_nth_page (GTK_NOTEBOOK (src), cur_page));
 
 	/* stop drag in origin window */
-	/* ungrab the pointer if it's grabbed */
 	drag_stop (src);
-	if (gdk_pointer_is_grabbed ())
-	{
-		gdk_pointer_ungrab (event->time);
-	}
 	gtk_grab_remove (GTK_WIDGET (src));
 
 	ephy_notebook_move_tab (src, dest, tab, dest_position);
 
 	/* start drag handling in dest notebook */
+	drag_start (dest);
 
 	dest->priv->motion_notify_handler_id =
 		g_signal_connect (G_OBJECT (dest),
 				  "motion-notify-event",
 				  G_CALLBACK (motion_notify_cb),
 				  NULL);
-
-	drag_start (dest, event->time);
 }
 
 static gboolean
@@ -538,14 +503,12 @@ button_release_cb (EphyNotebook *notebook,
 		/* ungrab the pointer if it's grabbed */
 		if (gdk_pointer_is_grabbed ())
 		{
-			gdk_pointer_ungrab (event->time);
+			gdk_pointer_ungrab (GDK_CURRENT_TIME);
+			gtk_grab_remove (GTK_WIDGET (notebook));
 		}
-		gtk_grab_remove (GTK_WIDGET (notebook));
 	}
-
 	/* This must be called even if a drag isn't happening */
 	drag_stop (notebook);
-
 	return FALSE;
 }
 
@@ -611,8 +574,7 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 				gint x, gint y, GtkSelectionData *selection_data,
 				guint info, guint time, EphyTab *tab)
 {
-	GList *uri_list = NULL;
-	gchar **tmp;
+	EphyWindow *window;
 
 	g_signal_stop_emission_by_name (widget, "drag_data_received");
 
@@ -620,37 +582,39 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 
 	if (selection_data->length <= 0 || selection_data->data == NULL) return;
 
+	window = EPHY_WINDOW (gtk_widget_get_toplevel (widget));
+
 	if (selection_data->target == gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE))
 	{
-		/* URL_TYPE has format: url \n title */
-		tmp = g_strsplit (selection_data->data, "\n", 2);
-		if (tmp != NULL && tmp[0] != NULL)
-		{
-			uri_list = g_list_prepend (uri_list, g_strdup (tmp[0]));
-		}
+		char *uris[2] = { NULL, NULL };
+		char **split;
 
-		g_strfreev (tmp);
+		/* URL_TYPE has format: url \n title */
+		split = g_strsplit (selection_data->data, "\n", 2);
+		if (split != NULL && split[0] != NULL)
+		{
+			uris[0] = split[0];
+			ephy_window_load_in_tabs (window, tab, uris);
+		}
+		g_strfreev (split);
 	}
 	else if (selection_data->target == gdk_atom_intern (EPHY_DND_URI_LIST_TYPE, FALSE))
 	{
-		uri_list = ephy_string_parse_uri_list (selection_data->data);
+		char **uris;
+
+		uris = gtk_selection_data_get_uris (selection_data);
+
+		if (uris != NULL)
+		{
+			ephy_window_load_in_tabs (window, tab, uris);
+
+			g_strfreev (uris);
+		}
 	}
 	else
 	{
 		g_return_if_reached ();
 	}
-
-	if (uri_list != NULL)
-	{
-		EphyWindow *window;
-
-		window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (widget)));
-
-		ephy_window_load_in_tabs (window, tab, uri_list);
-
-		g_list_foreach (uri_list, (GFunc) g_free, NULL);
-		g_list_free (uri_list);
-	}
 }
 
 /*
@@ -695,9 +659,6 @@ ephy_notebook_init (EphyNotebook *notebook)
 	g_object_ref (G_OBJECT (notebook->priv->title_tips));
 	gtk_object_sink (GTK_OBJECT (notebook->priv->title_tips));
 
-	notebook->priv->drag_in_progress = FALSE;
-	notebook->priv->motion_notify_handler_id = 0;
-	notebook->priv->focused_pages = NULL;
 	notebook->priv->show_tabs = TRUE;
 
 	g_signal_connect (notebook, "button-press-event",
@@ -811,7 +772,7 @@ sync_label (EphyTab *tab, GParamSpec *pspec, GtkWidget *proxy)
 
 	if (title)
 	{
-		ephy_label_set_text (EPHY_LABEL (label), title);
+		gtk_label_set_text (GTK_LABEL (label), title);
 		gtk_tooltips_set_tip (tips, ebox, title, NULL);
 	}
 }
@@ -851,7 +812,8 @@ tab_label_style_set_cb (GtkWidget *label,
 	LOG ("tab_label_size_request_cb label %p char_width %d total %d",
 	     label, char_width, TAB_WIDTH_N_CHARS * PANGO_PIXELS (char_width))
 
-	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (label),
+					   GTK_ICON_SIZE_MENU, &w, &h);
 
 	gtk_widget_set_size_request
 		(hbox, TAB_WIDTH_N_CHARS * PANGO_PIXELS(char_width) + 2 * w, -1);
@@ -860,12 +822,10 @@ tab_label_style_set_cb (GtkWidget *label,
 static GtkWidget *
 build_tab_label (EphyNotebook *nb, EphyTab *tab)
 {
-	GtkWidget *window, *hbox, *label_hbox, *label_ebox;
+	GtkWidget *hbox, *label_hbox, *label_ebox;
 	GtkWidget *label, *close_button, *image, *spinner, *icon;
 	GtkIconSize close_icon_size;
 
-	window = gtk_widget_get_toplevel (GTK_WIDGET (nb));
-
 	/* set hbox spacing and label padding (see below) so that there's an
 	 * equal amount of space around the label */
 	hbox = gtk_hbox_new (FALSE, 4);
@@ -881,14 +841,14 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	close_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (close_button),
 			       GTK_RELIEF_NONE);
-	/* don't allow focus on the close button */
-	gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
-
 	close_icon_size = gtk_icon_size_from_name (EPHY_ICON_SIZE_TAB_BUTTON);
 	image = gtk_image_new_from_stock (EPHY_STOCK_CLOSE_TAB, close_icon_size);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
 	gtk_box_pack_start (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 
+	gtk_tooltips_set_tip (nb->priv->title_tips, close_button,
+			      _("Close tab"), NULL);
+
 	g_signal_connect (G_OBJECT (close_button), "clicked",
                           G_CALLBACK (close_button_clicked_cb),
                           tab);
@@ -903,8 +863,8 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
 
 	/* setup label */
-        label = ephy_label_new ("");
-	ephy_label_set_ellipsize (EPHY_LABEL (label), PANGO_ELLIPSIZE_END);
+        label = gtk_label_new ("");
+	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_misc_set_padding (GTK_MISC (label), 0, 0);
 	gtk_box_pack_start (GTK_BOX (label_hbox), label, TRUE, TRUE, 0);
