@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.h,v 1.25.4.1 2004/07/10 18:45:23 chpe Exp $
+ *  $Id: ephy-shell.h,v 1.28 2004/09/13 10:24:56 chpe Exp $
  */
 
 #ifndef EPHY_SHELL_H
@@ -61,8 +62,7 @@ typedef enum
 	EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR	= 1 << 4,
 	EPHY_SHELL_STARTUP_SESSION		= 1 << 5,
 	EPHY_SHELL_STARTUP_IMPORT_BOOKMARKS	= 1 << 6,
-	EPHY_SHELL_STARTUP_ADD_BOOKMARK		= 1 << 7,
-	EPHY_SHELL_STARTUP_SERVER		= 1 << 8
+	EPHY_SHELL_STARTUP_ADD_BOOKMARK		= 1 << 7
 } EphyShellStartupFlags;
 
 typedef enum
@@ -76,7 +76,6 @@ typedef enum
 	EPHY_NEW_TAB_FULLSCREEN_MODE	= 1 << 4,
 
 	/* Tabs */
-	EPHY_NEW_TAB_APPEND_GROUPED	= 1 << 6,
 	EPHY_NEW_TAB_APPEND_LAST	= 1 << 7,
 	EPHY_NEW_TAB_APPEND_AFTER	= 1 << 8,
 	EPHY_NEW_TAB_JUMP		= 1 << 9,
@@ -109,19 +108,17 @@ gboolean	ephy_shell_startup			(EphyShell *shell,
 							 const char *string_arg,
 							 GError **error);
 
-EphyWindow     *ephy_shell_get_active_window		(EphyShell *shell);
-
 EphyTab	       *ephy_shell_new_tab			(EphyShell *shell,
 							 EphyWindow *parent_window,
 							 EphyTab *previous_tab,
 							 const char *url,
 							 EphyNewTabFlags flags);
 
-GObject	      *ephy_shell_get_session			(EphyShell *shell);
+GObject	       *ephy_shell_get_session			(EphyShell *shell);
 
 EphyBookmarks  *ephy_shell_get_bookmarks		(EphyShell *shell);
 
-GObject	      *ephy_shell_get_toolbars_model		(EphyShell *shell,
+GObject	       *ephy_shell_get_toolbars_model		(EphyShell *shell,
 							 gboolean fullscreen);
 
 GObject	       *ephy_shell_get_extensions_manager	(EphyShell *shell);
@@ -134,6 +131,8 @@ GObject        *ephy_shell_get_pdm_dialog		(EphyShell *shell);
 
 GObject        *ephy_shell_get_prefs_dialog		(EphyShell *shell);
 
+GObject	       *ephy_shell_get_print_setup_dialog	(EphyShell *shell);
+
 G_END_DECLS
 
 #endif
