@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c,v 1.40.4.2 2004/10/08 12:16:39 marco Exp $
+ *  $Id: pdm-dialog.c,v 1.48 2004/12/18 21:51:48 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "pdm-dialog.h"
 #include "ephy-shell.h"
@@ -30,7 +28,6 @@
 #include "ephy-file-helpers.h"
 #include "ephy-password-manager.h"
 #include "ephy-gui.h"
-#include "ephy-label.h"
 #include "ephy-debug.h"
 #include "ephy-state.h"
 
@@ -146,7 +143,7 @@ pdm_dialog_get_type (void)
 {
 	static GType type = 0;
 
-	if (type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -192,14 +189,14 @@ pdm_dialog_show_help (PdmDialog *pd)
 		"managing-passwords"
 	};
 
-	window = ephy_dialog_get_control (EPHY_DIALOG (pd), properties[PROP_WINDOW].id);
-	g_return_if_fail (GTK_IS_WINDOW (window));
-
-	notebook = ephy_dialog_get_control (EPHY_DIALOG (pd), properties[PROP_NOTEBOOK].id);
-	g_return_if_fail (notebook != NULL);
+	ephy_dialog_get_controls
+		(EPHY_DIALOG (pd),
+		 properties[PROP_WINDOW].id, &window,
+		 properties[PROP_NOTEBOOK].id, &notebook,
+		 NULL);
 
 	id = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
-	g_assert (id == 0 || id == 1);
+	g_return_if_fail (id == 0 || id == 1);
 
 	ephy_gui_help (GTK_WINDOW (window), "epiphany", help_preferences[id]);
 }
@@ -808,18 +805,18 @@ pdm_dialog_init (PdmDialog *dialog)
 
 	dialog->priv = EPHY_PDM_DIALOG_GET_PRIVATE (dialog);
 
-	dialog->priv->cookies = NULL;
-	dialog->priv->passwords = NULL;
-
 	ephy_dialog_construct (EPHY_DIALOG(dialog),
 			       properties,
 			       ephy_file ("epiphany.glade"),
 			       "pdm_dialog",
 			       NULL);
 
-	window = ephy_dialog_get_control (EPHY_DIALOG (dialog),
-					  properties[PROP_WINDOW].id);
-	ephy_gui_set_default_window_icon (GTK_WINDOW (window));
+	ephy_dialog_get_controls (EPHY_DIALOG (dialog),
+				  properties[PROP_WINDOW].id, &window,
+				  properties[PROP_NOTEBOOK].id, &notebook,
+				  NULL);
+
+	gtk_window_set_icon_name (GTK_WINDOW (window), "web-browser");
 
 	/**
 	 * Group all Properties and Remove buttons in the same size group to
@@ -862,7 +859,6 @@ pdm_dialog_init (PdmDialog *dialog)
 	cookies->construct (cookies);
 	passwords->construct (passwords);
 
-	notebook = ephy_dialog_get_control (EPHY_DIALOG (dialog), properties[PROP_NOTEBOOK].id);
 	sync_notebook_tab (notebook, NULL, 0, dialog);
 	g_signal_connect (G_OBJECT (notebook), "switch_page",
 			  G_CALLBACK (sync_notebook_tab), dialog);
@@ -904,8 +900,8 @@ show_cookies_properties (PdmDialog *dialog,
 
 	gdialog = gtk_dialog_new_with_buttons
 		 (_("Cookie Properties"),
-		  GTK_WINDOW(parent),
-		  GTK_DIALOG_MODAL,
+		  GTK_WINDOW (parent),
+		  GTK_DIALOG_DESTROY_WITH_PARENT,
 		  GTK_STOCK_CLOSE, 0, NULL);
 	ephy_state_add_window (GTK_WIDGET (gdialog), "cookie_properties", 
 			       -1, -1, FALSE,
@@ -928,16 +924,16 @@ show_cookies_properties (PdmDialog *dialog,
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 			  GTK_FILL, GTK_FILL, 0, 0);
 
-	label = ephy_label_new (info->value);
-	ephy_label_set_selectable (EPHY_LABEL (label), TRUE);
+	label = gtk_label_new (info->value);
+	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_widget_show (label);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 0, 1);
 
 	str = g_strconcat ("<b>", _("Path:"), "</b>", NULL);
-	label = ephy_label_new (str);
+	label = gtk_label_new (str);
 	g_free (str);
-	ephy_label_set_use_markup (EPHY_LABEL (label), TRUE);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_widget_show (label);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
@@ -997,7 +993,10 @@ show_cookies_properties (PdmDialog *dialog,
 			    table,
 			    FALSE, FALSE, 0);
 
-	gtk_dialog_run (GTK_DIALOG(gdialog));
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
+				     GTK_WINDOW (gdialog));
+
+	gtk_dialog_run (GTK_DIALOG (gdialog));
 
 	gtk_widget_destroy (gdialog);
 }
