@@ -1,4 +1,4 @@
-/*
+ /*
  *  Copyright (C) 200-2003 Marco Pesenti Gritti
  *  Copyright (C) 2003, 2004 Christian Persch
  *
@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.90 2004/10/23 16:49:10 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.103 2004/12/19 14:19:03 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "prefs-dialog.h"
 #include "ephy-dialog.h"
@@ -88,80 +86,255 @@ void language_editor_up_button_clicked_cb	(GtkWidget *button,
 void language_editor_down_button_clicked_cb	(GtkWidget *button,
 						 PrefsDialog *pd);
 
+#ifdef HAVE_ISO_CODES
+static const char *languages[] =
+{
+	/* If you're missing your language/locale combination, file a bug at
+	 * http://bugzilla.gnome.org/enter_bug.cgi?product=epiphany
+	 */
+	"af",
+	"am",
+	"an",
+	"ar",
+	"ar-ae",
+	"ar-bh",
+	"ar-dz",
+	"ar-eg",
+	"ar-iq",
+	"ar-jo",
+	"ar-kw",
+	"ar-lb",
+	"ar-ly",
+	"ar-ma",
+	"ar-om",
+	"ar-qa",
+	"ar-sa",
+	"ar-sy",
+	"ar-tn",
+	"ar-ye",
+	"ast",
+	"az",
+	"be",
+	"bg",
+	"bn",
+	"br",
+	"bs",
+	"ca",
+	"ce",
+	"ch",
+	"co",
+	"cs",
+	"cv",
+	"cy",
+	"da",
+	"de",
+	"de-at",
+	"de-ch",
+	"de-de",
+	"de-li",
+	"de-lu",
+	"el",
+	"en",
+	"en-au",
+	"en-bz",
+	"en-ca",
+	"en-gb",
+	"en-ie",
+	"en-jm",
+	"en-nz",
+	"en-ph",
+	"en-tt",
+	"en-us",
+	"en-za",
+	"en-zw",
+	"eo",
+	"es",
+	"es-ar",
+	"es-bo",
+	"es-cl",
+	"es-co",
+	"es-cr",
+	"es-do",
+	"es-ec",
+	"es-es",
+	"es-gt",
+	"es-hn",
+	"es-mx",
+	"es-ni",
+	"es-pa",
+	"es-pe",
+	"es-pr",
+	"es-py",
+	"es-sv",
+	"es-uy",
+	"es-ve",
+	"et",
+	"eu",
+	"fa",
+	"fi",
+	"fj",
+	"fo",
+	"fr",
+	"fr-be",
+	"fr-ca",
+	"fr-ch",
+	"fr-fr",
+	"fr-lu",
+	"fr-mc",
+	"fy",
+	"ga",
+	"gd",
+	"gl",
+	"gu",
+	"he",
+	"hsb",
+	"hi",
+	"hr",
+	"ht",
+	"hu",
+	"hy",
+	"ia",
+	"id",
+	"ie",
+	"is",
+	"it",
+	"it-ch",
+	"it-it",
+	"iu",
+	"ja",
+	"ka",
+	"kk",
+	"ko",
+	"ko-kp",
+	"ko-kr",
+	"ky",
+	"la",
+	"lb",
+	"li",
+	"lt",
+	"lv",
+	"mi",
+	"mk-mk",
+	"ml",
+	"mn",
+	"mo",
+	"mr",
+	"ms",
+	"nb",
+	"ne",
+	"ng",
+	"nl",
+	"nl-be",
+	"nn",
+	"no",
+	"nv",
+	"oc",
+	"om",
+	"pa",
+	"pl",
+	"pt",
+	"pt-br",
+	"qu",
+	"rm",
+	"ro",
+	"ru",
+	"sa",
+	"sc",
+	"sd",
+	"sg",
+	"sk",
+	"sl",
+	"so",
+	"sq",
+	"sr",
+	"sv",
+	"sv-fi",
+	"sw",
+	"ta",
+	"th",
+	"tk",
+	"tr",
+	"uk",
+	"ve",
+	"vi",
+	"vo",
+	"wa",
+	"xh",
+	"yi",
+	"zh",
+	"zh-cn",
+	"zh-hk",
+	"zh-sg",
+	"zh-tw",
+	"zu"
+};
+#else
 static const
 struct
 {
-	char *name;
 	char *code;
+	char *name;
 }
 languages [] =
 {
-	/**
-	 * please translate like this: "<your language> (System setting)"
-	 * Examples:
-	 * "de"    translation: "Deutsch (Systemeinstellung)"
-	 * "en_AU" translation: "English, Australia (System setting)" or
-	 *                      "Australian English (System setting)"
-	 */ 
-	{ N_("System language"), "system" },
-	{ N_("Afrikaans"), "ak" },
-	{ N_("Albanian"), "sq" },
-	{ N_("Arabic"), "ar" },
-	{ N_("Azerbaijani"), "az" },
-	{ N_("Basque"), "eu" },
-	{ N_("Breton"), "br" },
-	{ N_("Bulgarian"), "bg" },
-	{ N_("Byelorussian"), "be" },
-	{ N_("Catalan"), "ca" },
-	{ N_("Simplified Chinese"), "zh-cn" },
-	{ N_("Traditional Chinese"), "zh-tw" },
-	{ N_("Chinese"), "zh" },
-	{ N_("Croatian"), "hr" },
-	{ N_("Czech"), "cs" },
-	{ N_("Danish"), "da" },
-	{ N_("Dutch"), "nl" },
-	{ N_("English"), "en" },
-	{ N_("Esperanto"), "eo" },
-	{ N_("Estonian"), "et" },
-	{ N_("Faeroese"), "fo" },
-	{ N_("Finnish"), "fi" },
-	{ N_("French"), "fr" },
-	{ N_("Galician"), "gl" },
-	{ N_("German"), "de" },
-	{ N_("Greek"), "el" },
-	{ N_("Hebrew"), "he" },
-	{ N_("Hungarian"), "hu" },
-	{ N_("Icelandic"), "is" },
-	{ N_("Indonesian"), "id" },
-	{ N_("Irish"), "ga" },
-	{ N_("Italian"), "it" },
-	{ N_("Japanese"), "ja" },
-	{ N_("Korean"), "ko" },
-	{ N_("Latvian"), "lv" },
-	{ N_("Lithuanian"), "lt" },
-	{ N_("Macedonian"), "mk" },
-	{ N_("Malay"), "ms" },
-	{ N_("Norwegian/Nynorsk"), "nn" },
-	{ N_("Norwegian/Bokmal"), "nb" },
-	{ N_("Norwegian"), "no" },
-	{ N_("Polish"), "pl" },
-	{ N_("Portuguese"), "pt" },
-	{ N_("Portuguese of Brazil"), "pt-br" },
-	{ N_("Romanian"), "ro" },
-	{ N_("Russian"), "ru" },
-	{ N_("Scottish"), "gd" },
-	{ N_("Serbian"), "sr" },
-	{ N_("Slovak"), "sk" },
-	{ N_("Slovenian"), "sl" },
-	{ N_("Spanish"), "es" },
-	{ N_("Swedish"), "sv" },
-	{ N_("Tamil"), "ta" },
-	{ N_("Turkish"), "tr" },
-	{ N_("Ukrainian"), "uk" },
-	{ N_("Vietnamese"), "vi" },
-	{ N_("Walloon"), "wa" }
+	{ "af",		N_("Afrikaans") },
+	{ "ar",		N_("Arabic") },
+	{ "az",		N_("Azerbaijani") },
+	{ "be",		N_("Byelorussian") },
+	{ "bg",		N_("Bulgarian") },
+	{ "br",		N_("Breton") },
+	{ "ca",		N_("Catalan") },
+	{ "cs",		N_("Czech") },
+	{ "da",		N_("Danish") },
+	{ "de",		N_("German") },
+	{ "en",		N_("English") },
+	{ "el",		N_("Greek") },
+	{ "eo",		N_("Esperanto") },
+	{ "es",		N_("Spanish") },
+	{ "et",		N_("Estonian") },
+	{ "eu",		N_("Basque") },
+	{ "fi",		N_("Finnish") },
+	{ "fo",		N_("Faeroese") },
+	{ "fr",		N_("French") },
+	{ "ga",		N_("Irish") },
+	{ "gd",		N_("Scots Gaelic") },
+	{ "gl",		N_("Galician") },
+	{ "he",		N_("Hebrew") },
+	{ "hr",		N_("Croatian") },
+	{ "hu",		N_("Hungarian") },
+	{ "id",		N_("Indonesian") },
+	{ "is",		N_("Icelandic") },
+	{ "it",		N_("Italian") },
+	{ "ja",		N_("Japanese") },
+	{ "ko",		N_("Korean") },
+	{ "lt",		N_("Lithuanian") },
+	{ "lv",		N_("Latvian") },
+	{ "mk",		N_("Macedonian") },
+	{ "ms",		N_("Malay") },
+	{ "nl",		N_("Dutch") },
+	{ "nb",		N_("Norwegian/Bokmal") },
+	{ "nn",		N_("Norwegian/Nynorsk") },
+	{ "no",		N_("Norwegian") },
+	{ "pl",		N_("Polish") },
+	{ "pt",		N_("Portuguese") },
+	{ "pt-br",	N_("Portuguese of Brazil") },
+	{ "ro",		N_("Romanian") },
+	{ "ru",		N_("Russian") },
+	{ "sk",		N_("Slovak") },
+	{ "sl",		N_("Slovenian") },
+	{ "sq",		N_("Albanian") },
+	{ "sr",		N_("Serbian") },
+	{ "sv",		N_("Swedish") },
+	{ "ta",		N_("Tamil") },
+	{ "tr",		N_("Turkish") },
+	{ "uk",		N_("Ukrainian") },
+	{ "vi",		N_("Vietnamese") },
+	{ "wa",		N_("Walloon") },
+	{ "zh",		N_("Chinese") },
+	{ "zh-cn",	N_("Simplified Chinese") },
+	{ "zh-tw",	N_("Traditional Chinese") }
 };
-static guint n_languages = G_N_ELEMENTS (languages);
+#endif /* HAVE_ISO_CODES */
 
 static const
 char *cookies_accept_enum [] =
@@ -294,7 +467,8 @@ EphyDialogProperty properties [] =
 enum
 {
 	LANGUAGE_DIALOG,
-	LANGUAGE_PROP
+	LANGUAGE_PROP,
+	LANGUAGE_ACCEPT_BUTTON_PROP
 };
 
 static const
@@ -302,6 +476,7 @@ EphyDialogProperty add_lang_props [] =
 {
 	{ "add_language_dialog", NULL,	PT_NORMAL,	0 },
 	{ "languages_treeview",	 NULL,	PT_NORMAL,	G_TYPE_STRING },
+	{ "add_button",		 NULL,	PT_NORMAL,	0 },
 
 	{ NULL }
 };
@@ -336,8 +511,15 @@ struct PrefsDialogPrivate
 	GtkWidget *lang_remove_button;
 	GtkWidget *lang_up_button;
 	GtkWidget *lang_down_button;
+#ifdef HAVE_ISO_CODES
+	GHashTable *iso_639_table;
+	GHashTable *iso_3166_table;
+#endif
 };
 
+/* gtk+' gettext domain */
+#define GTK_DOMAIN "gtk20"
+
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -388,6 +570,11 @@ prefs_dialog_finalize (GObject *object)
 			 (gpointer *) &dialog->priv->download_dir_chooser);
 	}
 
+#ifdef HAVE_ISO_CODES
+	g_hash_table_destroy (dialog->priv->iso_639_table);
+	g_hash_table_destroy (dialog->priv->iso_3166_table);
+#endif
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -704,27 +891,41 @@ language_editor_update_buttons (PrefsDialog *dialog)
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GtkTreeIter iter;
+	gboolean can_remove = FALSE, can_move_up = FALSE, can_move_down = FALSE;
 	int selected;
 
 	selection = gtk_tree_view_get_selection (dialog->priv->lang_treeview);
 
-	gtk_widget_set_sensitive (dialog->priv->lang_remove_button, FALSE);
-	gtk_widget_set_sensitive (dialog->priv->lang_up_button, FALSE);
-	gtk_widget_set_sensitive (dialog->priv->lang_down_button, FALSE);
-	
 	if (gtk_tree_selection_get_selected (selection, &model, &iter))
 	{
 		path = gtk_tree_model_get_path (model, &iter);
 	
 		selected = gtk_tree_path_get_indices (path)[0];
-	
-		gtk_widget_set_sensitive (dialog->priv->lang_remove_button, TRUE);
-		gtk_widget_set_sensitive (dialog->priv->lang_up_button, selected > 0);
-		gtk_widget_set_sensitive (dialog->priv->lang_down_button,
-			selected < gtk_tree_model_iter_n_children (model, NULL) - 1);
+
+		can_remove = TRUE;
+		can_move_up = selected > 0;
+		can_move_down = 
+			selected < gtk_tree_model_iter_n_children (model, NULL) - 1;
 
 		gtk_tree_path_free (path);
 	}
+
+	gtk_widget_set_sensitive (dialog->priv->lang_remove_button, can_remove);
+	gtk_widget_set_sensitive (dialog->priv->lang_up_button, can_move_up);
+	gtk_widget_set_sensitive (dialog->priv->lang_down_button, can_move_down);
+}
+
+static void
+add_lang_dialog_selection_changed (GtkTreeSelection *selection,
+				   EphyDialog *dialog)
+{
+	GtkWidget *button;
+	int n_selected;
+
+	button = ephy_dialog_get_control (dialog, add_lang_props[LANGUAGE_ACCEPT_BUTTON_PROP].id);
+
+	n_selected = gtk_tree_selection_count_selected_rows (selection);
+	gtk_widget_set_sensitive (button, n_selected > 0);
 }
 
 static void
@@ -741,7 +942,7 @@ add_lang_dialog_response_cb (GtkWidget *widget,
 
 	g_return_if_fail (dialog != NULL);
 
-	if (response == GTK_RESPONSE_OK)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		treeview = GTK_TREE_VIEW (ephy_dialog_get_control
 				(dialog, add_lang_props[LANGUAGE_PROP].id));
@@ -779,6 +980,88 @@ add_lang_dialog_response_cb (GtkWidget *widget,
 	g_object_unref (dialog);
 }
 
+#ifdef HAVE_ISO_CODES
+static char *
+get_name_for_lang_code (PrefsDialog *pd,
+			const char *code)
+{
+	char **str;
+	char *name;
+	const char *langname, *localename;
+	int len;
+
+	str = g_strsplit (code, "-", -1);
+	len = g_strv_length (str);
+	g_return_val_if_fail (len != 0, NULL);
+
+	langname = (const char *) g_hash_table_lookup (pd->priv->iso_639_table, str[0]);
+
+	if (len == 1 && langname != NULL)
+	{
+		name = g_strdup (dgettext (ISO_639_DOMAIN, langname));
+	}
+	else if (len == 2 && langname != NULL)
+	{
+		localename = (const char *) g_hash_table_lookup (pd->priv->iso_3166_table, str[1]);
+
+		if (localename != NULL)
+		{
+			/* translators: the first %s is the language name, and the
+			 * second %s is the locale name. Example:
+			 * "French (France)"
+			 */
+			name = g_strdup_printf (Q_("language|%s (%s)"),
+						dgettext (ISO_639_DOMAIN, langname),
+						dgettext (ISO_3166_DOMAIN, localename));
+		}
+		else
+		{
+			name = g_strdup_printf (Q_("language|%s (%s)"),
+						dgettext (ISO_639_DOMAIN, langname), str[1]);
+		}
+	}
+	else
+	{
+		/* translators: this refers to a user-define language code
+		 * (one which isn't in our built-in list).
+		 */
+		name = g_strdup_printf (Q_("language|User defined (%s)"), code);
+	}
+
+	g_strfreev (str);
+
+	return name;
+}
+#endif /* HAVE_ISO_CODES */
+
+static void
+add_system_language_entry (GtkListStore *store)
+{
+	GtkTreeIter iter;
+	char **sys_langs;
+	char *system, *text;
+	int n_sys_langs;
+
+	sys_langs = ephy_langs_get_languages ();
+	n_sys_langs = g_strv_length (sys_langs);
+
+	system = g_strjoinv (", ", sys_langs);
+
+	text = g_strdup_printf
+		(ngettext ("System language (%s)",
+			   "System languages (%s)", n_sys_langs), system);
+
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    COL_LANG_NAME, text,
+			    COL_LANG_CODE, "system",
+			    -1);
+
+	g_strfreev (sys_langs);
+	g_free (system);
+	g_free (text);
+}
+
 static EphyDialog *
 setup_add_language_dialog (PrefsDialog *pd)
 {
@@ -809,16 +1092,31 @@ setup_add_language_dialog (PrefsDialog *pd)
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 
-	for (i = 0; i < n_languages; i++)
+	for (i = 0; i < G_N_ELEMENTS (languages); i++)
 	{
-		gtk_list_store_append (store, &iter);
+#ifdef HAVE_ISO_CODES
+		const char *code = languages[i];
+		char *name;
 
+		name = get_name_for_lang_code (pd, code);
+		
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    COL_LANG_NAME, name,
+				    COL_LANG_CODE, code,
+				    -1);
+		g_free (name);
+#else
+		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
 				    COL_LANG_NAME, _(languages[i].name),
 				    COL_LANG_CODE, languages[i].code,
 				    -1);
+#endif /* HAVE_ISO_CODES */
 	}
 
+	add_system_language_entry (store);
+
 	sortmodel = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (store));
 	gtk_tree_sortable_set_sort_column_id
 		(GTK_TREE_SORTABLE (sortmodel), COL_LANG_NAME, GTK_SORT_ASCENDING);
@@ -847,6 +1145,10 @@ setup_add_language_dialog (PrefsDialog *pd)
 
 	selection = gtk_tree_view_get_selection (treeview);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+	
+	add_lang_dialog_selection_changed (GTK_TREE_SELECTION (selection), dialog);
+	g_signal_connect (selection, "changed",
+			  G_CALLBACK (add_lang_dialog_selection_changed), dialog);
 
 	g_signal_connect (window, "response",
 			  G_CALLBACK (add_lang_dialog_response_cb), pd);
@@ -980,6 +1282,11 @@ create_language_section (EphyDialog *dialog)
 	GtkTreeSelection *selection;
 	GSList *list, *l, *ulist = NULL;
 
+#ifdef HAVE_ISO_CODES
+	pd->priv->iso_639_table = ephy_langs_iso_639_table ();
+	pd->priv->iso_3166_table = ephy_langs_iso_3166_table ();
+#endif
+
 	ephy_dialog_get_controls
 		(dialog,
 		 properties[LANGUAGE_TREEVIEW_PROP].id, &treeview,
@@ -1045,7 +1352,24 @@ create_language_section (EphyDialog *dialog)
 	for (l = ulist; l != NULL; l = l->next)
 	{
 		const char *code = (const char *) l->data;
-		int i;
+
+#ifdef HAVE_ISO_CODES
+		if (strcmp (code, "system") == 0)
+		{
+			add_system_language_entry (store);
+		}
+		else if (code[0] != '\0')
+		{
+			char *text;
+
+			text = get_name_for_lang_code (pd, code);
+			language_editor_add (pd, code, text);
+			g_free (text);
+		}
+
+#else /* !HAVE_ISO_CODES */
+
+		int i, n_languages = G_N_ELEMENTS (languages);
 
 		for (i = 0; i < n_languages; i++)
 		{
@@ -1055,16 +1379,25 @@ create_language_section (EphyDialog *dialog)
 		/* code isn't in stock list */
 		if (i == n_languages)
 		{
-			char *text;
-
-			text = g_strdup_printf (_("Custom [%s]"), code);
-			language_editor_add (pd, code, text);
-			g_free (text);
+			if (strcmp (code, "system") != 0)
+			{
+				char *text;
+	
+				text = g_strdup_printf (Q_("language|User defined (%s)"), code);
+	
+				language_editor_add (pd, code, text);
+				g_free (text);
+			}
+			else
+			{
+				add_system_language_entry (store);
+			}
 		}
 		else
 		{
 			language_editor_add (pd, code, _(languages[i].name));
 		}
+#endif /* HAVE_ISO_CODES */
 	}
 
 	language_editor_update_buttons (pd);
@@ -1098,24 +1431,17 @@ get_download_button_label ()
 
 	if (key == NULL || g_utf8_collate (key, "~") == 0)
 	{
-		/* Note that this does NOT refer to the home page but to a
-		 * user's home folder. It should be translated by the same
-		 * term as GTK+'s "Home" string to be consistent with the
-		 * filechooser */
-		label = g_strdup (_("Home"));
+		label = g_strdup (dgettext (GTK_DOMAIN, "Home"));
 	}
 	else if ((converted_dp != NULL && g_utf8_collate (key, converted_dp) == 0) ||
 		 g_utf8_collate (key, "Downloads") == 0)
 	{
 		label = g_strdup (_("Downloads"));
 	}
-	else if (g_utf8_collate (key, "~/Desktop") == 0)
+	else if (g_utf8_collate (key, "~/Desktop") == 0 ||
+	         g_utf8_collate (key, "Desktop") == 0)
 	{
-		label = g_strdup (_("Desktop")); 
-	}
-	else if (g_utf8_collate (key, "Desktop") == 0)
-	{
-		label = g_strdup (_("Desktop")); 
+		label = g_strdup (dgettext (GTK_DOMAIN, "Desktop"));
 	}
 	else
 	{
@@ -1168,11 +1494,6 @@ prefs_dialog_init (PrefsDialog *pd)
 	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
 			      n_cookies_accept_enum, cookies_accept_enum);
 
-	ephy_dialog_set_size_group (dialog,
-				    properties[DEFAULT_ENCODING_LABEL_PROP].id,
-				    properties[AUTO_ENCODING_LABEL_PROP].id,
-				    NULL);
-
 	ephy_dialog_get_controls
 		(dialog,
 		 properties[WINDOW_PROP].id, &window,
