@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: toolbar.c,v 1.87 2004/11/01 14:48:55 chpe Exp $
+ *  $Id: toolbar.c,v 1.90 2004/12/18 19:40:08 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "toolbar.h"
 #include "ephy-favicon-action.h"
@@ -313,6 +311,9 @@ toolbar_setup_actions (Toolbar *t)
 			       "label", _("Back"),
 			       "stock_id", GTK_STOCK_GO_BACK,
 			       "tooltip", _("Go back"),
+			       /* this is the tooltip on the Back button's drop-down arrow, which will show
+			        * a menu with all sites you can go 'back' to
+				*/
 			       "arrow-tooltip", _("Back history"),
 			       "window", t->priv->window,
 			       "direction", EPHY_NAVIGATION_DIRECTION_BACK,
@@ -328,6 +329,9 @@ toolbar_setup_actions (Toolbar *t)
 			       "label", _("Forward"),
 			       "stock_id", GTK_STOCK_GO_FORWARD,
 			       "tooltip", _("Go forward"),
+			       /* this is the tooltip on the Forward button's drop-down arrow, which will show
+				* a menu with all sites you can go 'forward' to
+				*/
 			       "arrow-tooltip", _("Forward history"),
 			       "window", t->priv->window,
 			       "direction", EPHY_NAVIGATION_DIRECTION_FORWARD,
@@ -342,6 +346,9 @@ toolbar_setup_actions (Toolbar *t)
 			       "label", _("Up"),
 			       "stock_id", GTK_STOCK_GO_UP,
 			       "tooltip", _("Go up one level"),
+			       /* this is the tooltip on the Up button's drop-down arrow, which will show
+				* a menu with al sites you can go 'up' to
+				*/
 			       "arrow-tooltip", _("List of upper levels"),
 			       "window", t->priv->window,
 			       "direction", EPHY_NAVIGATION_DIRECTION_UP,
@@ -632,14 +639,18 @@ toolbar_update_navigation_actions (Toolbar *t, gboolean back, gboolean forward,
 }
 
 void
-toolbar_update_zoom (Toolbar *t, float zoom)
+toolbar_update_zoom (Toolbar *t,
+		     gboolean can_zoom,
+		     float zoom)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
 
 	action_group = t->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "Zoom");
-	g_object_set (action, "zoom", zoom, NULL);
+	g_object_set (action, "zoom", can_zoom ? zoom : 1.0,
+			      "sensitive", can_zoom,
+			      NULL);
 }
 
 Toolbar *
